@@ -1,3 +1,4 @@
+import queue
 import time
 from multiprocessing import Process, Queue
 from queue import Empty
@@ -16,7 +17,7 @@ class GenericPipe(Process, Generic[R, S]):
         self._source = source
         self._target = target
         self._timeout: Optional[float] = 0.1
-        Timer(0.015, self.start).start()
+        Timer(0.01, self.start).start()
 
     @staticmethod
     def is_death_packet(p: Any) -> bool:
@@ -66,6 +67,8 @@ class GenericPipe(Process, Generic[R, S]):
                     return
                 processed = self._perform_task(data)
                 self._send_to_next(processed)
+            except queue.Empty:
+                pass
             except Exception as e:
                 if str(e.__class__) == "<class '_queue.Empty'>":
                     continue
