@@ -1,5 +1,7 @@
+import queue
 from multiprocessing import Queue
 from typing import Callable, TypeVar
+
 from .generic import GenericPipe
 
 R = TypeVar("R")
@@ -30,6 +32,8 @@ class ReducePipe(GenericPipe[R, T]):
                     self._kill(data)
                     return
                 self._perform_task(data)
+            except queue.Empty:
+                pass
             except Exception as e:
                 if str(e.__class__) == "<class '_queue.Empty'>":
                     continue
