@@ -1,6 +1,8 @@
+import queue
 import time
 from multiprocessing import Queue
 from typing import Iterable, List, Optional, TypeVar
+
 from .generic import GenericPipe
 
 R = TypeVar("R")
@@ -49,7 +51,8 @@ class TimeBatchPipe(GenericPipe[R, Iterable[R]]):
                 processed = self._perform_task(data)
                 if processed is not None:
                     self._send_to_next(processed)
-
+            except queue.Empty:
+                pass
             except Exception:
                 self._send_to_next(self._datas)
                 self._datas = []
